@@ -13,17 +13,17 @@ use fs_err as fs;
 use target_lexicon::{OperatingSystem, Triple};
 
 /// Zig linker wrapper
-#[derive(Debug, clap::Parser)]
+#[derive(Debug, clap::Subcommand)]
 pub enum Zig {
     /// `zig cc` wrapper
-    #[clap(name = "cc", setting = clap::AppSettings::TrailingVarArg)]
+    #[clap(name = "cc", trailing_var_arg = true)]
     Cc {
         /// `zig cc` arguments
         #[clap(takes_value = true, multiple_values = true)]
         args: Vec<String>,
     },
     /// `zig c++` wrapper
-    #[clap(name = "c++", setting = clap::AppSettings::TrailingVarArg)]
+    #[clap(name = "c++", trailing_var_arg = true)]
     Cxx {
         /// `zig c++` arguments
         #[clap(takes_value = true, multiple_values = true)]
@@ -113,8 +113,6 @@ impl Zig {
     }
 
     /// Search for `python -m ziglang` first and for `zig` second.
-    /// That way we use the zig from `maturin[ziglang]` first,
-    /// but users or distributions can also insert their own zig
     pub fn find_zig() -> Result<(String, Vec<String>)> {
         Self::find_zig_python()
             .or_else(|_| Self::find_zig_bin())
@@ -225,8 +223,8 @@ fn write_linker_wrapper(path: &Path, command: &str, args: &str) -> Result<()> {
         .truncate(true)
         .mode(0o700)
         .open(path)?;
-    let current_exe = if let Ok(maturin) = env::var("CARGO_BIN_EXE_maturin") {
-        PathBuf::from(maturin)
+    let current_exe = if let Ok(exe) = env::var("CARGO_BIN_EXE_cargo_zigbuild") {
+        PathBuf::from(exe)
     } else {
         env::current_exe()?
     };
